sbsv2/raptor/python/raptor_version.py
changeset 590 360bd6b35136
parent 0 044383f39525
child 616 24e4ef208cca
--- a/sbsv2/raptor/python/raptor_version.py	Wed Jun 16 16:51:40 2010 +0300
+++ b/sbsv2/raptor/python/raptor_version.py	Wed Jun 23 16:56:47 2010 +0800
@@ -1,20 +1,27 @@
-#
-# Copyright (c) 2006-2009 Nokia Corporation and/or its subsidiary(-ies).
-# All rights reserved.
-# This component and the accompanying materials are made available
-# under the terms of the License "Eclipse Public License v1.0"
-# which accompanies this distribution, and is available
-# at the URL "http://www.eclipse.org/legal/epl-v10.html".
-#
-# Initial Contributors:
-# Nokia Corporation - initial contribution.
-#
-# Contributors:
-#
-# Description: 
-# raptor version information module
-#
-
-def Version():
-	"""Raptor version string"""
-	return "2.10.1 [2009-10-27 sf prerelease]"
+#
+# Copyright (c) 2006-2010 Nokia Corporation and/or its subsidiary(-ies).
+# All rights reserved.
+# This component and the accompanying materials are made available
+# under the terms of the License "Eclipse Public License v1.0"
+# which accompanies this distribution, and is available
+# at the URL "http://www.eclipse.org/legal/epl-v10.html".
+#
+# Initial Contributors:
+# Nokia Corporation - initial contribution.
+#
+# Contributors:
+#
+# Description: 
+# raptor version information module
+
+# replace CHANGESET with the Hg changeset for ANY release
+
+version=(2,14,0,"2010-05-19","symbian build system","CHANGESET")
+
+def numericversion():
+	"""Raptor version string"""
+	return "%d.%d.%d" % version[:3]
+
+def fullversion():
+	"""Raptor version string"""
+	return "%d.%d.%d [%s %s %s]" % version